"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Get = void 0;
const os = require("os");
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const config_1 = require("../../config");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-config', 'get');
class Get extends config_1.ConfigCommand {
    async run() {
        const argv = await this.parseArgs();
        if (!argv || argv.length === 0) {
            throw messages.createError('NoConfigKeysFound');
        }
        else {
            const results = [];
            argv.forEach((configName) => {
                try {
                    const configInfo = this.configAggregator.getInfo(configName);
                    results.push(configInfo);
                    this.responses.push({
                        name: configName,
                        value: configInfo.value,
                        success: true,
                        location: configInfo.location,
                    });
                }
                catch (err) {
                    this.responses.push({
                        name: configName,
                        success: false,
                        error: err,
                    });
                }
            });
            this.output('Get Config', this.flags.verbose);
            return results;
        }
    }
}
exports.Get = Get;
Get.description = messages.getMessage('description');
Get.examples = messages.getMessage('examples').split(os.EOL);
Get.strict = false;
Get.flagsConfig = {
    verbose: command_1.flags.builtin(),
};
Get.aliases = ['force:config:get'];
//# sourceMappingURL=get.js.map